@@ -71,6 +71,7 @@ bool listen_stdin;
 bool configured;
 bool verbose;
 int tls;
+const char *process_name;
 
 volatile int quit;
 #ifndef WIN32
@@ -91,6 +92,12 @@ threadlocal_get_context (void)
   abort ();
 }
 
+int
+threadlocal_set_timestamp (char *timestamp)
+{
+  abort ();
+}
+
 conn_status
 connection_get_status (void)
 {
